Module empty_spec
ebml_
iterable_
specification
0.4.0
Module empty_
spec
Module Items
Structs
In crate ebml_
iterable_
specification
ebml_iterable_specification
Module
empty_
spec
Contains an empty specification for use with examples or very basic testing.
Structs

Empty
Spec
An empty specification for use with examples or testing.